==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/table-view/EditTableView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/table-view/EditTableView.es", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../components/control-menu/ControlMenu.es', '../../components/drag-and-drop/DragLayer.es', '../../components/loading/Loading.es', '../../components/upper-toolbar/UpperToolbar.es', '../../utils/client.es', './DropZone.es', './EditTableViewContext.es', './EditTableViewContextProvider.es', './TableViewSidebar.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _ControlMenu = _interopRequireDefault(require("../../components/control-menu/ControlMenu.es"));

  var _DragLayer = _interopRequireDefault(require("../../components/drag-and-drop/DragLayer.es"));

  var _Loading = require("../../components/loading/Loading.es");

  var _UpperToolbar = _interopRequireDefault(require("../../components/upper-toolbar/UpperToolbar.es"));

  var _client = require("../../utils/client.es");

  var _DropZone = _interopRequireDefault(require("./DropZone.es"));

  var _EditTableViewContext = _interopRequireWildcard(require("./EditTableViewContext.es"));

  var _EditTableViewContextProvider = _interopRequireDefault(require("./EditTableViewContextProvider.es"));

  var _TableViewSidebar = _interopRequireDefault(require("./TableViewSidebar.es"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var EditTableView = (0, _reactRouterDom.withRouter)(function (_ref) {
    var history = _ref.history;

    var _useContext = (0, _react.useContext)(_EditTableViewContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        _useContext2$ = _useContext2[0],
        dataDefinition = _useContext2$.dataDefinition,
        dataListView = _useContext2$.dataListView,
        dispatch = _useContext2[1];

    var title = Liferay.Language.get('new-table-view');

    if (dataListView.id) {
      title = Liferay.Language.get('edit-table-view');
    }

    var validate = function validate() {
      var name = dataListView.name.en_US.trim();

      if (!name) {
        return null;
      }

      return _objectSpread({}, dataListView, {
        name: {
          en_US: name
        }
      });
    };

    var handleSubmit = function handleSubmit() {
      var dataListView = validate();

      if (dataListView === null) {
        return;
      }

      if (dataListView.id) {
        (0, _client.updateItem)("/o/data-engine/v2.0/data-list-views/".concat(dataListView.id), dataListView).then(function () {
          return history.goBack();
        });
      } else {
        (0, _client.addItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinition.id, "/data-list-views"), dataListView).then(function () {
          return history.goBack();
        });
      }
    };

    var dataDefinitionFields = dataDefinition.dataDefinitionFields;
    var fieldNames = dataListView.fieldNames,
        dataListViewName = dataListView.name.en_US;

    var _useState = (0, _react.useState)(false),
        _useState2 = _slicedToArray(_useState, 2),
        isSidebarClosed = _useState2[0],
        setSidebarClosed = _useState2[1];

    var onAddFieldName = function onAddFieldName(fieldName) {
      var index = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      dispatch({
        payload: {
          fieldName: fieldName,
          index: index
        },
        type: _EditTableViewContext.ADD_DATA_LIST_VIEW_FIELD
      });
      dispatch({
        payload: {
          fieldName: fieldName
        },
        type: _EditTableViewContext.UPDATE_FOCUSED_COLUMN
      });
    };

    return _react["default"].createElement("div", {
      className: "app-builder-table-view"
    }, _react["default"].createElement(_ControlMenu["default"], {
      backURL: "../",
      title: title
    }), _react["default"].createElement(_Loading.Loading, {
      isLoading: dataDefinition === null
    }, _react["default"].createElement(_DragLayer["default"], null), _react["default"].createElement("form", {
      onSubmit: function onSubmit(event) {
        event.preventDefault();
        handleSubmit();
      }
    }, _react["default"].createElement(_UpperToolbar["default"], null, _react["default"].createElement(_UpperToolbar["default"].Input, {
      onInput: function onInput(event) {
        var name = event.target.value;
        dispatch({
          payload: {
            name: name
          },
          type: _EditTableViewContext.UPDATE_DATA_LIST_VIEW_NAME
        });
      },
      placeholder: Liferay.Language.get('untitled-table-view'),
      value: dataListViewName
    }), _react["default"].createElement(_UpperToolbar["default"].Group, null, _react["default"].createElement(_UpperToolbar["default"].Button, {
      displayType: "secondary",
      onClick: function onClick() {
        return history.goBack();
      }
    }, Liferay.Language.get('cancel')), _react["default"].createElement(_UpperToolbar["default"].Button, {
      disabled: dataListViewName.trim() === '',
      onClick: handleSubmit
    }, Liferay.Language.get('save'))))), _react["default"].createElement(_TableViewSidebar["default"], {
      onAddFieldName: onAddFieldName,
      onClose: function onCloseSidebar(closed) {
        return setSidebarClosed(closed);
      }
    }), _react["default"].createElement("div", {
      className: (0, _classnames["default"])('app-builder-sidebar-content', {
        closed: isSidebarClosed
      })
    }, _react["default"].createElement("div", {
      className: "container table-view-container"
    }, _react["default"].createElement(_DropZone["default"], {
      fields: fieldNames.map(function (fieldName) {
        return _objectSpread({}, dataDefinitionFields.find(function (_ref2) {
          var name = _ref2.name;
          return name === fieldName;
        }));
      }),
      onAddFieldName: onAddFieldName,
      onRemoveFieldName: function onRemoveFieldName(fieldName) {
        dispatch({
          payload: {
            fieldName: fieldName
          },
          type: _EditTableViewContext.REMOVE_DATA_LIST_VIEW_FIELD
        });
      }
    })))));
  });

  var _default = function _default(props) {
    return _react["default"].createElement(_EditTableViewContextProvider["default"], null, _react["default"].createElement(EditTableView, props));
  };

  exports["default"] = _default;
  //# sourceMappingURL=EditTableView.es.js.map
});
//# sourceMappingURL=EditTableView.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/table-view/EditTableView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/table-view/EditTableView.es", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../components/control-menu/ControlMenu.es', '../../components/drag-and-drop/DragLayer.es', '../../components/loading/Loading.es', '../../components/toast/ToastContext.es', '../../components/upper-toolbar/UpperToolbar.es', '../../utils/client.es', './DropZone.es', './EditTableViewContext.es', './EditTableViewContextProvider.es', './TableViewSidebar.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _ControlMenu = _interopRequireDefault(require("../../components/control-menu/ControlMenu.es"));

  var _DragLayer = _interopRequireDefault(require("../../components/drag-and-drop/DragLayer.es"));

  var _Loading = require("../../components/loading/Loading.es");

  var _ToastContext = require("../../components/toast/ToastContext.es");

  var _UpperToolbar = _interopRequireDefault(require("../../components/upper-toolbar/UpperToolbar.es"));

  var _client = require("../../utils/client.es");

  var _DropZone = _interopRequireDefault(require("./DropZone.es"));

  var _EditTableViewContext = _interopRequireWildcard(require("./EditTableViewContext.es"));

  var _EditTableViewContextProvider = _interopRequireDefault(require("./EditTableViewContextProvider.es"));

  var _TableViewSidebar = _interopRequireDefault(require("./TableViewSidebar.es"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var EditTableView = (0, _reactRouterDom.withRouter)(function (_ref) {
    var history = _ref.history;

    var _useContext = (0, _react.useContext)(_EditTableViewContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        _useContext2$ = _useContext2[0],
        dataDefinition = _useContext2$.dataDefinition,
        dataListView = _useContext2$.dataListView,
        dispatch = _useContext2[1];

    var _useContext3 = (0, _react.useContext)(_ToastContext.ToastContext),
        addToast = _useContext3.addToast;

    var title = Liferay.Language.get('new-table-view');

    if (dataListView.id) {
      title = Liferay.Language.get('edit-table-view');
    }

    var onError = function onError(error) {
      var _error$title = error.title,
          message = _error$title === void 0 ? '' : _error$title;
      addToast({
        displayType: 'danger',
        message: _react["default"].createElement(_react["default"].Fragment, null, message, '.'),
        title: "".concat(Liferay.Language.get('error'), ":")
      });
    };

    var validate = function validate() {
      var name = dataListView.name.en_US.trim();

      if (!name) {
        return null;
      }

      return _objectSpread({}, dataListView, {
        name: {
          en_US: name
        }
      });
    };

    var handleSubmit = function handleSubmit() {
      var dataListView = validate();

      if (dataListView === null) {
        return;
      }

      if (dataListView.id) {
        (0, _client.updateItem)("/o/data-engine/v2.0/data-list-views/".concat(dataListView.id), dataListView).then(function () {
          return history.goBack();
        })["catch"](function (error) {
          onError(error);
        });
      } else {
        (0, _client.addItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinition.id, "/data-list-views"), dataListView).then(function () {
          return history.goBack();
        })["catch"](function (error) {
          onError(error);
        });
      }
    };

    var dataDefinitionFields = dataDefinition.dataDefinitionFields;
    var fieldNames = dataListView.fieldNames,
        dataListViewName = dataListView.name.en_US;

    var _useState = (0, _react.useState)(false),
        _useState2 = _slicedToArray(_useState, 2),
        isSidebarClosed = _useState2[0],
        setSidebarClosed = _useState2[1];

    var onAddFieldName = function onAddFieldName(fieldName) {
      var index = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      dispatch({
        payload: {
          fieldName: fieldName,
          index: index
        },
        type: _EditTableViewContext.ADD_DATA_LIST_VIEW_FIELD
      });
    };

    return _react["default"].createElement("div", {
      className: "app-builder-table-view"
    }, _react["default"].createElement(_ControlMenu["default"], {
      backURL: "../",
      title: title
    }), _react["default"].createElement(_Loading.Loading, {
      isLoading: dataDefinition === null
    }, _react["default"].createElement(_DragLayer["default"], null), _react["default"].createElement("form", {
      onSubmit: function onSubmit(event) {
        event.preventDefault();
        handleSubmit();
      }
    }, _react["default"].createElement(_UpperToolbar["default"], null, _react["default"].createElement(_UpperToolbar["default"].Input, {
      onInput: function onInput(event) {
        var name = event.target.value;
        dispatch({
          payload: {
            name: name
          },
          type: _EditTableViewContext.UPDATE_DATA_LIST_VIEW_NAME
        });
      },
      placeholder: Liferay.Language.get('untitled-table-view'),
      value: dataListViewName
    }), _react["default"].createElement(_UpperToolbar["default"].Group, null, _react["default"].createElement(_UpperToolbar["default"].Button, {
      displayType: "secondary",
      onClick: function onClick() {
        return history.goBack();
      }
    }, Liferay.Language.get('cancel')), _react["default"].createElement(_UpperToolbar["default"].Button, {
      disabled: dataListViewName.trim() === '',
      onClick: handleSubmit
    }, Liferay.Language.get('save'))))), _react["default"].createElement(_TableViewSidebar["default"], {
      onAddFieldName: onAddFieldName,
      onClose: function onCloseSidebar(closed) {
        return setSidebarClosed(closed);
      }
    }), _react["default"].createElement("div", {
      className: (0, _classnames["default"])('data-layout-builder-sidebar-content', {
        closed: isSidebarClosed
      })
    }, _react["default"].createElement("div", {
      className: "container table-view-container"
    }, _react["default"].createElement(_DropZone["default"], {
      fields: fieldNames.map(function (fieldName) {
        return _objectSpread({}, dataDefinitionFields.find(function (_ref2) {
          var name = _ref2.name;
          return name === fieldName;
        }));
      }),
      onAddFieldName: onAddFieldName,
      onRemoveFieldName: function onRemoveFieldName(fieldName) {
        dispatch({
          payload: {
            fieldName: fieldName
          },
          type: _EditTableViewContext.REMOVE_DATA_LIST_VIEW_FIELD
        });
      }
    })))));
  });

  var _default = function _default(props) {
    return _react["default"].createElement(_EditTableViewContextProvider["default"], null, _react["default"].createElement(_ToastContext.ToastContextProvider, null, _react["default"].createElement(EditTableView, props)));
  };

  exports["default"] = _default;
  //# sourceMappingURL=EditTableView.es.js.map
});
//# sourceMappingURL=EditTableView.es.js.map
